@@ -27,6 +27,11 @@ instance PutQueue TMVar STM where
   put = putTMVar
 
 
+instance TakeQueue TChan STM where
+  take = readTChan
+instance PutQueue TChan STM where
+  put = writeTChan
+
 newtype Take = Take Take
 newtype Put = Put Put
 newtype TakePut = TakePut TakePut
